/* $Id: GenericContextFactory.java 711 2009-10-09 20:34:17Z hohwille $
 * Copyright (c) The m-m-m Team, Licensed under the Apache License, Version 2.0
 * http://www.apache.org/licenses/LICENSE-2.0 */
package net.sf.mmm.util.context.api;

import java.util.Map;

import net.sf.mmm.util.collection.api.MapFactory;

/**
 * This is the interface for a factory of generic {@link MutableGenericContext
 * contexts}.
 * 
 * @author Joerg Hohwiller (hohwille at users.sourceforge.net)
 * @since 1.1.0
 */
public interface GenericContextFactory {

  /**
   * This method creates a new instance of a {@link MutableGenericContext}. It
   * will use a {@link net.sf.mmm.util.collection.base.HashMapFactory} and
   * delegate to {@link #createContext(MapFactory)}.<br>
   * <b>ATTENTION:</b><br>
   * Such context is usually suitable even if
   * {@link GenericContext#createChildContext() child-contexts} are created and
   * passed to other threads while the original thread is modifying the original
   * context as proved in the according test-case. However
   * {@link java.util.HashMap#get(Object)} is not academically thread-safe so if
   * you need mission-critical safety, you might want to pass
   * {@link net.sf.mmm.util.collection.base.ConcurrentHashMapFactory} to
   * {@link #createContext(MapFactory)}.
   * 
   * @return the new context.
   */
  MutableGenericContext createContext();

  /**
   * This method creates a new instance of a {@link MutableGenericContext} using
   * the given {@link MapFactory}.
   * 
   * @param mapFactory is the factory used to create maps for the underlying
   *        context.
   * @return the new context.
   */
  @SuppressWarnings("unchecked")
  MutableGenericContext createContext(MapFactory<? extends Map> mapFactory);

}
